@@ -12,11 +12,11 @@ COPS::Client - COPS Protocol - Packet Cable Client
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -1568,6 +1568,15 @@ my $auth = ${$data}{'Type'} & 0x01;
 my $reserved = ${$data}{'Type'} & 0x02;
 my $commit = ${$data}{'Type'} & 0x04;
 
+# For you code part I think for the DOCSIS Service Class Name, if stype is 2 [snum/stype/len 7/2/16],
+# you need to ignore auth, reserve and commit
+# In this context $parts[1] = snum $parts[2] = stype
+# we set auth, reserved and commit to 0 as we dont need them
+if ( $parts[2]==2 )
+	{
+	$auth=0; $reserved=0; $commit=0;
+	}
+
 print "Auth is '$auth'\n" if $self->{_GLOBAL}{'DEBUG'}>0;
 print "Reserved is '$reserved'\n" if $self->{_GLOBAL}{'DEBUG'}>0;
 print "Commit is '$commit'\n" if $self->{_GLOBAL}{'DEBUG'}>0;
